darkhistory.electrons.ics.ics_engloss_spectrum — DarkHistory documentation

# darkhistory.electrons.ics.ics_engloss_spectrum

Nonrelativistic ICS spectrum after integrating over CMB.

Functions

`engloss_spec`(eleckineng, delta, T[, …]) | Thomson ICS scattered electron energy loss spectrum.
`engloss_spec_diff`(eleckineng, delta, T[, …]) | Thomson ICS scattered electron energy loss spectrum, beta expansion.
`engloss_spec_series`(eleckineng, delta, T[, …]) | Thomson ICS scattered electron energy loss spectrum, series method.

#### Previous topic

darkhistory.electrons.ics.ics_cooling.get_ics_cooling_tf_fast

#### Next topic

darkhistory.electrons.ics.ics_engloss_spectrum.engloss_spec

### This Page

Show Source